ams.core.service.ValueService
=============================

.. currentmodule:: ams.core.service

.. autoclass:: ValueService

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: _generated/

   
       
       
          ~ValueService.assign_memory
       
       
          ~ValueService.evaluate
       
       
          ~ValueService.get_names
       
       
          ~ValueService.parse
       
       
          ~ValueService.update
       
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: _generated/

   
      ~ValueService.class_name
      ~ValueService.n
      ~ValueService.shape
      ~ValueService.size
      ~ValueService.v
   
   